==> qewd-2.46.9.tgz: package/up/examples/cache/ms-db/db_service/list/list.js <==
/*

 ----------------------------------------------------------------------------
 | QEWD-Up Demonstration of Document Database Functionality                 |
 |                                                                          |
 | Copyright (c) 2018 M/Gateway Developments Ltd,                           |
 | Reigate, Surrey UK.                                                      |
 | All rights reserved.                                                     |
 |                                                                          |
 | http://www.mgateway.com                                                  |
 | Email: rtweed@mgateway.com                                               |
 |                                                                          |
 |                                                                          |
 | Licensed under the Apache License, Version 2.0 (the "License");          |
 | you may not use this file except in compliance with the License.         |
 | You may obtain a copy of the License at                                  |
 |                                                                          |
 |     http://www.apache.org/licenses/LICENSE-2.0                           |
 |                                                                          |
 | Unless required by applicable law or agreed to in writing, software      |
 | distributed under the License is distributed on an "AS IS" BASIS,        |
 | WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
 | See the License for the specific language governing permissions and      |
 |  limitations under the License.                                          |
 ----------------------------------------------------------------------------

  13 December 2018

*/


module.exports = function(documentName, docSubName, showDetail) {
  if (showDetail === 'true') showDetail = true;
  if (typeof docSubName === 'undefined' || docSubName === '') {
    return {error: 'Document name not defined or empty'};
  }
  var doc = this.db.use(documentName, docSubName);
  if (!doc.exists) {
    return {error: 'No ' + documentName + ' Documents exist'};
  }
  var results = [];
  if (showDetail) results = {};
  doc.forEachChild(function(id, node) {
    if (showDetail) {
      results[id] = node.getDocument(true);
    }
    else {
      results.push(id);
    }
  });
  return results;
};

==> qewd-2.51.15.tgz: package/up/examples/cache/ms-db/db_service/list/list.js <==
/*

 ----------------------------------------------------------------------------
 | QEWD-Up Demonstration of Document Database Functionality                 |
 |                                                                          |
 | Copyright (c) 2023 MGateway Ltd,                                         |
 | Banstead, Surrey UK.                                                     |
 | All rights reserved.                                                     |
 |                                                                          |
 | https://www.mgateway.com                                                 |
 | Email: rtweed@mgateway.com                                               |
 |                                                                          |
 |                                                                          |
 | Licensed under the Apache License, Version 2.0 (the "License");          |
 | you may not use this file except in compliance with the License.         |
 | You may obtain a copy of the License at                                  |
 |                                                                          |
 |     http://www.apache.org/licenses/LICENSE-2.0                           |
 |                                                                          |
 | Unless required by applicable law or agreed to in writing, software      |
 | distributed under the License is distributed on an "AS IS" BASIS,        |
 | WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
 | See the License for the specific language governing permissions and      |
 |  limitations under the License.                                          |
 ----------------------------------------------------------------------------

  13 December 2018

*/


module.exports = function(documentName, docSubName, showDetail) {
  if (showDetail === 'true') showDetail = true;
  if (typeof docSubName === 'undefined' || docSubName === '') {
    return {error: 'Document name not defined or empty'};
  }
  var doc = this.db.use(documentName, docSubName);
  if (!doc.exists) {
    return {error: 'No ' + documentName + ' Documents exist'};
  }
  var results = [];
  if (showDetail) results = {};
  doc.forEachChild(function(id, node) {
    if (showDetail) {
      results[id] = node.getDocument(true);
    }
    else {
      results.push(id);
    }
  });
  return results;
};
